@@ -121,3 +121,5 @@ from .ssh_utils import *
 from .env_utils import *
 from .path_utils import *
 from .file_utils import *
+from .file_utils import call_for_all_tabs
+from .string_utils import *
